@@ -11,6 +11,7 @@
 
 #include "lokalize_debug.h"
 
+#include "gettextheaderparser.h"
 #include "project.h"
 
 #include "version.h"
@@ -57,7 +58,7 @@ static const langPInfo langsWithPInfo[] = {
     { "eo", "nplurals=2; plural=(n != 1);" },
     { "es", "nplurals=2; plural=(n != 1);" },
     { "et", "nplurals=2; plural=(n != 1);" },
-    { "fa", "nplurals=1; plural=0;" },
+    { "fa", "nplurals=2; plural=(n > 1);" },
     { "fi", "nplurals=2; plural=(n != 1);" },
     { "fo", "nplurals=2; plural=(n != 1);" },
     { "fr", "nplurals=2; plural=(n > 1);" },
@@ -121,7 +122,7 @@ int numberOfPluralFormsFromHeader(const QString& header)
     QRegExp rxplural(QStringLiteral("Plural-Forms:\\s*nplurals=(.);"));
     if (rxplural.indexIn(header) == -1)
         return 0;
-    bool ok;
+    bool ok{};
     int result = rxplural.cap(1).toShort(&ok);
     return ok ? result : 0;
 
@@ -223,7 +224,7 @@ QString GNUPluralForms(const QString& lang)
         return def;
     }
 
-    return QString(result.mid(pos, end - pos - 2));
+    return QString::fromLatin1(result.mid(pos, end - pos - 2));
     //END alternative
 }
 
@@ -234,7 +235,7 @@ QString formatGettextDate(const QDateTime &dt)
     const int offset_seconds = dt.offsetFromUtc();
     const int offset_hours = abs(offset_seconds) / 3600;
     const int offset_minutes = abs(offset_seconds % 3600) / 60;
-    QString zoneOffsetString = (offset_seconds >= 0 ? '+' : '-') + (offset_hours < 10 ? QStringLiteral("0") : QStringLiteral("")) + QString::number(offset_hours) + (offset_minutes < 10 ? QStringLiteral("0") : QStringLiteral("")) + QString::number(offset_minutes);
+    QString zoneOffsetString = (offset_seconds >= 0 ? QLatin1Char('+') : QLatin1Char('-')) + (offset_hours < 10 ? QStringLiteral("0") : QString()) + QString::number(offset_hours) + (offset_minutes < 10 ? QStringLiteral("0") : QString()) + QString::number(offset_minutes);
 
     return dateTimeString + zoneOffsetString;
 }
@@ -251,14 +252,12 @@ void updateHeader(QString& header,
 {
     askAuthorInfoIfEmpty();
 
-    QStringList headerList(header.split('\n', Qt::SkipEmptyParts));
-    QStringList commentList(comment.split('\n', Qt::SkipEmptyParts));
+    QStringList headerList(header.split(QLatin1Char('\n'), Qt::SkipEmptyParts));
+    QStringList commentList(comment.split(QLatin1Char('\n'), Qt::SkipEmptyParts));
 
 //BEGIN header itself
     QStringList::Iterator it, ait;
     QString temp;
-    QString authorNameEmail;
-
     const QString BACKSLASH_N = QStringLiteral("\\n");
 
     // Unwrap header since the following code
@@ -279,22 +278,9 @@ void updateHeader(QString& header,
         }
     }
 
+    GetTextHeaderParser::updateLastTranslator(headerList, Settings::authorName(), Settings::authorEmail());
+
     bool found = false;
-    authorNameEmail = Settings::authorName();
-    if (!Settings::authorEmail().isEmpty())
-        authorNameEmail += (QStringLiteral(" <") + Settings::authorEmail() + '>');
-    temp = QStringLiteral("Last-Translator: ") + authorNameEmail + BACKSLASH_N;
-
-    QRegExp lt(QStringLiteral("^ *Last-Translator:.*"));
-    for (it = headerList.begin(), found = false; it != headerList.end() && !found; ++it) {
-        if (it->contains(lt)) {
-            if (forSaving) *it = temp;
-            found = true;
-        }
-    }
-    if (Q_UNLIKELY(!found))
-        headerList.append(temp);
-
     temp = QStringLiteral("PO-Revision-Date: ") + formatGettextDate(QDateTime::currentDateTime()) + BACKSLASH_N;
     QRegExp poRevDate(QStringLiteral("^ *PO-Revision-Date:.*"));
     for (it = headerList.begin(), found = false; it != headerList.end() && !found; ++it) {
@@ -359,8 +345,6 @@ void updateHeader(QString& header,
             mailingList = Settings::defaultMailingList();
     }
 
-
-
     Project::LangSource projLangSource = Project::instance()->languageSource();
     QString projLT = Project::instance()->projLangTeam();
     if (projLangSource == Project::LangSource::Project) {
@@ -386,7 +370,7 @@ void updateHeader(QString& header,
     if (Q_UNLIKELY(!found))
         headerList.append(temp);
 
-    temp = QStringLiteral("Content-Type: text/plain; charset=") + codec->name() + BACKSLASH_N;
+    temp = QStringLiteral("Content-Type: text/plain; charset=") + QString::fromLatin1(codec->name()) + BACKSLASH_N;
     QRegExp ctRe(QStringLiteral("^ *Content-Type:.*"));
     for (it = headerList.begin(), found = false; it != headerList.end() && !found; ++it) {
         found = it->contains(ctRe);
@@ -465,182 +449,14 @@ void updateHeader(QString& header,
     if (Q_UNLIKELY(!found))
         headerList.append(temp);
 
-    //m_header.setMsgstr( headerList.join( "\n" ) );
     header = headerList.join(QStringLiteral("\n"));
 //END header itself
 
 //BEGIN comment = description, copyrights
-    QLocale cLocale(QLocale::C);
-    // U+00A9 is the Copyright sign
-    QRegExp fsfc(QStringLiteral("^# *Copyright (\\(C\\)|\\x00a9).*Free Software Foundation, Inc"));
-    for (it = commentList.begin(), found = false; it != commentList.end() && !found; ++it) {
-        found = it->contains(fsfc) ;
-        if (found) {
-            it->replace(QStringLiteral("YEAR"), cLocale.toString(QDate::currentDate(), QStringLiteral("yyyy")));
-        }
-    }
-    /*
-                                    if( saveOptions.FSFCopyright == ProjectSettingsBase::Update )
-                                    {
-                                        //update years
-                                        QString cy = cLocale.toString(QDate::currentDate(), "yyyy");
-                                        if( !it->contains( QRegExp(cy)) ) // is the year already included?
-                                        {
-                                        int index = it->lastIndexOf( QRegExp("[\\d]+[\\d\\-, ]*") );
-                                        if( index == -1 )
-                                        {
-                                            KMessageBox::information(nullptr,i18n("Free Software Foundation Copyright does not contain any year. "
-                                            "It will not be updated."));
-                                        } else {
-                                            it->insert(index+1, QString(", ")+cy);
-                                        }
-                                        }
-                                    }*/
-#if 0
-    if ((!usePrefs || saveOptions.updateDescription)
-        && (!saveOptions.descriptionString.isEmpty())) {
-        temp = "# " + saveOptions.descriptionString;
-        temp.replace("@PACKAGE@", packageName());
-        temp.replace("@LANGUAGE@", identityOptions.languageName);
-        temp = temp.trimmed();
-
-        // The description strings has often buggy variants already in the file, these must be removed
-        QString regexpstr = "^#\\s+" + QRegExp::escape(saveOptions.descriptionString.trimmed()) + "\\s*$";
-        regexpstr.replace("@PACKAGE@", ".*");
-        regexpstr.replace("@LANGUAGE@", ".*");
-        //qCDebug(LOKALIZE_LOG) << "REGEXPSTR: " <<  regexpstr;
-        QRegExp regexp(regexpstr);
-
-        // The buggy variants exist in English too (of a time before KBabel got a translation for the corresponding language)
-        QRegExp regexpUntranslated("^#\\s+translation of .* to .*\\s*$");
-
-
-        qCDebug(LOKALIZE_LOG) << "Temp is '" << temp << "'";
-
-        found = false;
-        bool foundTemplate = false;
-
-        it = commentList.begin();
-        while (it != commentList.end()) {
-            qCDebug(LOKALIZE_LOG) << "testing '" << (*it) << "'";
-            bool deleteItem = false;
-
-            if ((*it) == temp) {
-                qCDebug(LOKALIZE_LOG) << "Match ";
-                if (found)
-                    deleteItem = true;
-                else
-                    found = true;
-            } else if (regexp.indexIn(*it) >= 0) {
-                // We have a similar (translated) string (from another project or another language (perhaps typos)). Remove it.
-                deleteItem = true;
-            } else if (regexpUntranslated.indexIn(*it) >= 0) {
-                // We have a similar (untranslated) string (from another project or another language (perhaps typos)). Remove it.
-                deleteItem = true;
-            } else if ((*it) == "# SOME DESCRIPTIVE TITLE.") {
-                // We have the standard title placeholder, remove it
-                deleteItem = true;
-            }
-
-            if (deleteItem)
-                it = commentList.erase(it);
-            else
-                ++it;
-        }
-        if (!found) commentList.prepend(temp);
-    }
-#endif
+    GetTextHeaderParser::updateGeneralCopyrightYear(commentList);
     // qCDebug(LOKALIZE_LOG) << "HEADER COMMENT: " << commentList;
 
-    /*    if ( (!usePrefs || saveOptions.updateTranslatorCopyright)
-            && ( ! identityOptions->readEntry("authorName","").isEmpty() )
-            && ( ! identityOptions->readEntry("Email","").isEmpty() ) ) // An email address can be used as ersatz of a name
-        {*/
-//                        return;
-    QStringList foundAuthors;
-
-    temp = QStringLiteral("# ") + authorNameEmail + QStringLiteral(", ") + cLocale.toString(QDate::currentDate(), QStringLiteral("yyyy")) + '.';
-
-    // ### TODO: it would be nice if the entry could start with "COPYRIGHT" and have the "(C)" symbol (both not mandatory)
-    QRegExp regexpAuthorYear(QStringLiteral("^#.*(<.+@.+>)?,\\s*([\\d]+[\\d\\-, ]*|YEAR)"));
-    QRegExp regexpYearAlone(QStringLiteral("^# , \\d{4}.?\\s*$"));
-    if (commentList.isEmpty()) {
-        commentList.append(temp);
-        commentList.append(QString());
-    } else {
-        it = commentList.begin();
-        while (it != commentList.end()) {
-            bool deleteItem = false;
-            if (it->indexOf(QLatin1String("copyright"), 0, Qt::CaseInsensitive) != -1) {
-                // We have a line with a copyright. It should not be moved.
-            } else if (it->contains(QRegExp(QStringLiteral("#, *fuzzy"))))
-                deleteItem = true;
-            else if (it->contains(regexpYearAlone)) {
-                // We have found a year number that is preceded by a comma.
-                // That is typical of KBabel 1.10 (and earlier?) when there is neither an author name nor an email
-                // Remove the entry
-                deleteItem = true;
-            } else if (it->contains(QLatin1String("# FIRST AUTHOR <EMAIL@ADDRESS>, YEAR.")))
-                deleteItem = true;
-            else if (it->contains(QLatin1String("# SOME DESCRIPTIVE TITLE")))
-                deleteItem = true;
-            else if (it->contains(regexpAuthorYear)) {   // email address followed by year
-                if (!foundAuthors.contains((*it))) {
-                    // The author line is new (and not a duplicate), so add it to the author line list
-                    foundAuthors.append((*it));
-                }
-                // Delete also non-duplicated entry, as now all what is needed will be processed in foundAuthors
-                deleteItem = true;
-            }
-
-            if (deleteItem)
-                it = commentList.erase(it);
-            else
-                ++it;
-        }
-
-        if (!foundAuthors.isEmpty()) {
-            found = false;
-            bool foundAuthor = false;
-
-            const QString cy = cLocale.toString(QDate::currentDate(), QStringLiteral("yyyy"));
-
-            ait = foundAuthors.end();
-            for (it = foundAuthors.begin() ; it != foundAuthors.end(); ++it) {
-                if (it->contains(Settings::authorName()) || it->contains(Settings::authorEmail())) {
-                    foundAuthor = true;
-                    if (it->contains(cy))
-                        found = true;
-                    else
-                        ait = it;
-                }
-            }
-            if (!found) {
-                if (!foundAuthor)
-                    foundAuthors.append(temp);
-                else if (ait != foundAuthors.end()) {
-                    //update years
-                    const int index = (*ait).lastIndexOf(QRegExp(QStringLiteral("[\\d]+[\\d\\-, ]*")));
-                    if (index == -1)
-                        (*ait) += QStringLiteral(", ") + cy;
-                    else
-                        ait->insert(index + 1, QStringLiteral(", ") + cy);
-                } else
-                    qCDebug(LOKALIZE_LOG) << "INTERNAL ERROR: author found but iterator dangling!";
-            }
-
-        } else
-            foundAuthors.append(temp);
-
-
-        for (QString author : qAsConst(foundAuthors)) {
-            // ensure dot at the end of copyright
-            if (!author.endsWith(QLatin1Char('.'))) author += QLatin1Char('.');
-            commentList.append(author);
-        }
-    }
-
-    //m_header.setComment( commentList.join( "\n" ) );
+    GetTextHeaderParser::updateAuthors(commentList, Settings::authorName(), Settings::authorEmail());
     comment = commentList.join(QStringLiteral("\n"));
 
 //END comment = description, copyrights
@@ -655,7 +471,7 @@ bool askAuthorInfoIfEmpty()
     if (QThread::currentThread() == qApp->thread()) {
 
         if (Settings::authorName().isEmpty()) {
-            bool ok;
+            bool ok{};
             QString contact = QInputDialog::getText(
                                   SettingsController::instance()->mainWindowPtr(),
                                   i18nc("@window:title", "Author name missing"), i18n("Your name:"),
