@@ -23,21 +23,19 @@
 MergeCatalog::MergeCatalog(QObject* parent, Catalog* baseCatalog, bool saveChanges)
     : Catalog(parent)
     , m_baseCatalog(baseCatalog)
-    , m_unmatchedCount(0)
-    , m_modified(false)
 {
     setActivePhase(baseCatalog->activePhase(), baseCatalog->activePhaseRole());
     if (saveChanges) {
         connect(baseCatalog, &Catalog::signalEntryModified, this, &MergeCatalog::copyFromBaseCatalogIfInDiffIndex);
-        connect(baseCatalog, QOverload<>::of(&Catalog::signalFileSaved), this, &MergeCatalog::save);
+        connect(baseCatalog, qOverload<>(&Catalog::signalFileSaved), this, &MergeCatalog::save);
     }
 }
 
 void MergeCatalog::copyFromBaseCatalog(const DocPosition& pos, int options)
 {
-    bool a = m_mergeDiffIndex.contains(pos.entry);
-    bool b = m_mergeEmptyIndex.contains(pos.entry);
-    if (options & EvenIfNotInDiffIndex || !a || b) {
+    bool a = std::find(m_mergeDiffIndex.begin(), m_mergeDiffIndex.end(), pos.entry) != m_mergeDiffIndex.end();
+    bool b = std::find(m_mergeEmptyIndex.begin(), m_mergeEmptyIndex.end(), pos.entry) != m_mergeEmptyIndex.end();
+    if (options & EvenIfNotInDiffIndex || !a|| b) {
         //sync changes
         DocPosition ourPos = pos;
         if ((ourPos.entry = m_map.at(ourPos.entry)) == -1)
@@ -51,13 +49,13 @@ void MergeCatalog::copyFromBaseCatalog(const DocPosition& pos, int options)
         if (!m_originalHashes.contains(p))
             m_originalHashes[p] = qHash(m_storage->target(ourPos));
         m_storage->setTarget(ourPos, m_baseCatalog->target(pos));
-        setModified(ourPos, true);
+        setModified(DocPos(ourPos), true);
 
         if (options & EvenIfNotInDiffIndex && a)
-            m_mergeDiffIndex.removeAll(pos.entry);
+            m_mergeDiffIndex.remove(pos.entry);
         if (b) {
-            m_mergeEmptyIndex.removeAll(pos.entry);
-            m_mergeDiffIndex.removeAll(pos.entry);
+            m_mergeEmptyIndex.remove(pos.entry);
+            m_mergeDiffIndex.remove(pos.entry);
         }
 
         m_modified = true;
@@ -108,7 +106,7 @@ MatchItem MergeCatalog::calcMatchItem(const DocPosition& basePos, const DocPosit
     CatalogStorage& baseStorage = *(m_baseCatalog->m_storage);
     CatalogStorage& mergeStorage = *(m_storage);
 
-    MatchItem item(mergePos.entry, basePos.entry, true, mergeStorage.target(mergePos.entry).isEmpty());
+    MatchItem item(mergePos.entry, basePos.entry, true, mergeStorage.target(DocPosition(mergePos.entry)).isEmpty());
     //TODO make more robust, perhaps after XLIFF?
     QStringList baseMatchData = baseStorage.matchData(basePos);
     QStringList mergeMatchData = mergeStorage.matchData(mergePos);
@@ -145,7 +143,7 @@ MatchItem MergeCatalog::calcMatchItem(const DocPosition& basePos, const DocPosit
 
 static QString strip(QString source)
 {
-    source.remove('\n');
+    source.remove(QLatin1Char('\n'));
     return source;
 }
 
@@ -161,8 +159,8 @@ int MergeCatalog::loadFromUrl(const QString& filePath, const QString& saidFilePa
     CatalogStorage& mergeStorage = *(m_storage);
 
     DocPosition i(0);
-    int size = baseStorage.size();
-    int mergeSize = mergeStorage.size();
+    const int size = baseStorage.size();
+    const int mergeSize = mergeStorage.size();
     m_map.fill(-1, size);
     QMultiMap<int, int> backMap; //will be used to maintain one-to-one relation
 
@@ -176,26 +174,26 @@ int MergeCatalog::loadFromUrl(const QString& filePath, const QString& saidFilePa
 
     i.entry = 0;
     while (i.entry < size) {
-        QString key = strip(baseStorage.source(i));
+        const QString key = strip(baseStorage.source(i));
         const QList<int>& entries = mergeMap.values(key);
         QList<MatchItem> scores;
 
-        int k = entries.size();
-        if (k) {
-            while (--k >= 0)
-                scores << calcMatchItem(i, DocPosition(entries.at(k)));
+        for (const auto entry : qAsConst(entries)) {
+            scores << calcMatchItem(i, DocPosition(entry));
+        }
 
+        if (!scores.isEmpty()) {
             std::sort(scores.begin(), scores.end(), std::greater<MatchItem>());
 
             m_map[i.entry] = scores.first().mergeEntry;
             backMap.insert(scores.first().mergeEntry, i.entry);
 
             if (scores.first().translationIsDifferent)
-                m_mergeDiffIndex.append(i.entry);
+                m_mergeDiffIndex.push_back(i.entry);
             if (scores.first().translationIsEmpty)
-                m_mergeEmptyIndex.append(i.entry);
-
+                m_mergeEmptyIndex.push_back(i.entry);
         }
+
         ++(i.entry);
     }
 
@@ -210,7 +208,7 @@ int MergeCatalog::loadFromUrl(const QString& filePath, const QString& saidFilePa
         //qCDebug(LOKALIZE_LOG)<<"kv"<<mergePosition<<basePositions;
         QList<MatchItem> scores;
         for (int value : basePositions)
-            scores << calcMatchItem(DocPosition(value), mergePosition);
+            scores << calcMatchItem(DocPosition(value), DocPosition(mergePosition));
 
         std::sort(scores.begin(), scores.end(), std::greater<MatchItem>());
         int i = scores.size();
@@ -283,7 +281,7 @@ void MergeCatalog::copyToBaseCatalog(int options)
     DocPosition pos;
     pos.offset = 0;
     bool insHappened = false;
-    const QLinkedList<int> changed = differentEntries();
+    const std::list<int> &changed = differentEntries();
     for (int entry : changed) {
         pos.entry = entry;
         if (options & EmptyOnly && !m_baseCatalog->isEmpty(entry))
@@ -325,3 +323,4 @@ void MergeCatalog::copyToBaseCatalog(int options)
     }
 }
 
+#include "moc_mergecatalog.cpp"
