@@ -31,12 +31,10 @@ MergeView::MergeView(QWidget* parent, Catalog* catalog, bool primary)
     : QDockWidget(primary ? i18nc("@title:window that displays difference between current file and 'merge source'", "Primary Sync") : i18nc("@title:window that displays difference between current file and 'merge source'", "Secondary Sync"), parent)
     , m_browser(new QTextEdit(this))
     , m_baseCatalog(catalog)
-    , m_mergeCatalog(nullptr)
     , m_normTitle(primary ?
                   i18nc("@title:window that displays difference between current file and 'merge source'", "Primary Sync") :
                   i18nc("@title:window that displays difference between current file and 'merge source'", "Secondary Sync"))
-    , m_hasInfoTitle(m_normTitle + " [*]")
-    , m_hasInfo(false)
+    , m_hasInfoTitle(m_normTitle + QLatin1String(" [*]"))
     , m_primary(primary)
 {
     setObjectName(primary ? QStringLiteral("mergeView-primary") : QStringLiteral("mergeView-secondary"));
@@ -136,15 +134,15 @@ void MergeView::slotNewEntryDisplayed(const DocPosition& pos)
 #endif
 
     if (!m_mergeCatalog->isApproved(pos.entry)) {
-        result.prepend("<i>");
-        result.append("</i>");
+        result.prepend(QLatin1String("<i>"));
+        result.append(QLatin1String("</i>"));
     }
 
-    if (m_mergeCatalog->isModified(pos)) {
-        result.prepend("<b>");
-        result.append("</b>");
+    if (m_mergeCatalog->isModified(DocPos(pos))) {
+        result.prepend(QLatin1String("<b>"));
+        result.append(QLatin1String("</b>"));
     }
-    result.replace(' ', QChar::Nbsp);
+    result.replace(QLatin1Char(' '), QChar::Nbsp);
     m_browser->setHtml(result);
     //qCDebug(LOKALIZE_LOG)<<"ELA "<<time.elapsed();
 }
@@ -203,7 +201,7 @@ void MergeView::mergeOpen(QString mergeFilePath)
     if (!QFile::exists(mergeFilePath)) {
         saidMergeFilePath = mergeFilePath;
         saidMergeFilePath.replace(Project::instance()->branchDir(), Project::instance()->branchPotDir());
-        saidMergeFilePath += 't';
+        saidMergeFilePath += QLatin1Char('t');
 
         if (QFile::exists(saidMergeFilePath))
             std::swap(mergeFilePath, saidMergeFilePath);
@@ -227,17 +225,9 @@ void MergeView::mergeOpen(QString mergeFilePath)
     } else {
         //KMessageBox::error(this, KIO::NetAccess::lastErrorString() );
         cleanup();
-        if (errorLine > 0)
+        if (errorLine > 0) {
             KMessageBox::error(this, i18nc("@info", "Error opening the file <filename>%1</filename> for synchronization, error line: %2", mergeFilePath, errorLine));
-        else {
-            /* disable this as requested by bug 272587
-            KNotification* notification=new KNotification("MergeFilesOpenError");
-            notification->setWidget(this);
-            notification->setText( i18nc("@info %1 is full filename","Error opening the file <filename>%1</filename> for synchronization",url.pathOrUrl()) );
-            notification->sendEvent();
-            */
         }
-        //i18nc("@info %1 is w/o path","No branch counterpart for <filename>%1</filename>",url.fileName()),
     }
 
 }
@@ -348,11 +338,10 @@ void MergeView::mergeAcceptAllForEmpty()
 {
     if (Q_UNLIKELY(!m_mergeCatalog)) return;
 
-    bool update = m_mergeCatalog->differentEntries().contains(m_pos.entry);
-
+    bool containsBefore = std::find(m_mergeCatalog->differentEntries().begin(), m_mergeCatalog->differentEntries().end(), m_pos.entry) != m_mergeCatalog->differentEntries().end();
     m_mergeCatalog->copyToBaseCatalog(/*MergeCatalog::EmptyOnly*/MergeCatalog::HigherOnly);
-
-    if (update != m_mergeCatalog->differentEntries().contains(m_pos.entry))
+    bool containsAfter = std::find(m_mergeCatalog->differentEntries().begin(), m_mergeCatalog->differentEntries().end(), m_pos.entry) != m_mergeCatalog->differentEntries().end();
+    if (containsBefore != containsAfter)
         Q_EMIT gotoEntry(m_pos, 0);
 }
 
@@ -362,11 +351,12 @@ bool MergeView::event(QEvent *event)
     if (event->type() == QEvent::ToolTip && m_mergeCatalog) {
         QHelpEvent *helpEvent = static_cast<QHelpEvent *>(event);
         QString text = QStringLiteral("<b>") + QDir::toNativeSeparators(filePath()) + QStringLiteral("</b>\n") + i18nc("@info:tooltip", "Different entries: %1\nUnmatched entries: %2",
-                       m_mergeCatalog->differentEntries().count(), m_mergeCatalog->unmatchedCount());
-        text.replace('\n', QStringLiteral("<br />"));
+                       m_mergeCatalog->differentEntries().size(), m_mergeCatalog->unmatchedCount());
+        text.replace(QLatin1Char('\n'), QLatin1String("<br />"));
         QToolTip::showText(helpEvent->globalPos(), text);
         return true;
     }
     return QDockWidget::event(event);
 }
 
+#include "moc_mergeview.cpp"
