@@ -98,12 +98,8 @@ Project* Project::instance()
 }
 
 Project::Project()
-    : ProjectBase()
-    , m_localConfig(new ProjectLocal())
-    , m_model(nullptr)
+    : m_localConfig(new ProjectLocal())
     , m_glossary(new GlossaryNS::Glossary(this))
-    , m_glossaryWindow(nullptr)
-    , m_tmManagerWindow(nullptr)
 {
     setDefaults();
     /*
@@ -160,12 +156,12 @@ void Project::load(const QString &newProjectPath, const QString& forcedTargetLan
     m_localConfig->setSharedConfig(KSharedConfig::openConfig(projectID() + QStringLiteral(".local"), KConfig::NoGlobals, QStandardPaths::DataLocation));
     m_localConfig->load();
 
-    if (forcedTargetLangCode.length())
+    if (!forcedTargetLangCode.isEmpty())
         setLangCode(forcedTargetLangCode);
     else if (langCode().isEmpty())
         setLangCode(QLocale::system().name());
 
-    if (forcedProjectId.length())
+    if (!forcedProjectId.isEmpty())
         setProjectID(forcedProjectId);
 
 
@@ -230,7 +226,7 @@ QString Project::absolutePath(const QString& possiblyRelPath) const
 QString Project::relativePath(const QString& possiblyAbsPath) const
 {
     if (QFileInfo(possiblyAbsPath).isAbsolute()) {
-        if (projectDir().endsWith('/'))
+        if (projectDir().endsWith(QLatin1Char('/')))
             return QString(possiblyAbsPath).remove(projectDir());
         return QString(possiblyAbsPath).remove(projectDir() + QLatin1Char('/'));
     }
@@ -307,7 +303,7 @@ bool Project::isFileMissing(const QString& filePath) const
         //check if we are opening template
         QString newPath = filePath;
         newPath.replace(poDir(), potDir());
-        if (!QFile::exists(newPath) && !QFile::exists(newPath += 't')) {
+        if (!QFile::exists(newPath) && !QFile::exists(newPath += QLatin1Char('t'))) {
             return true;
         }
     }
@@ -335,7 +331,7 @@ QString Project::branchPotDir() const
 {
     QDir poDir = Project::poDir();
     QString potDirRelativelyToPoDir = poDir.relativeFilePath(Project::potDir());
-    QDir branchPotDir (Project::branchDir() + '/' + potDirRelativelyToPoDir);
+    QDir branchPotDir (Project::branchDir() + QLatin1Char('/') + potDirRelativelyToPoDir);
     return absolutePath(branchPotDir.absolutePath());
 }
 
@@ -395,7 +391,7 @@ static void fillFilePathsRecursive(const QDir& dir, QMultiMap<QByteArray, QByteA
 class SourceFilesSearchJob: public KJob
 {
 public:
-    SourceFilesSearchJob(const QString& folderName, QObject* parent = nullptr);
+    explicit SourceFilesSearchJob(const QString& folderName, QObject* parent = nullptr);
     void start() override;
     void finish()
     {
@@ -459,10 +455,6 @@ const QMultiMap<QByteArray, QByteArray>& Project::sourceFilePaths()
             SourceFilesSearchJob* metaJob = new SourceFilesSearchJob(local()->sourceDir());
             KIO::getJobTracker()->registerJob(metaJob);
             metaJob->start();
-
-            //KNotification* notification=new KNotification("SourceFileScan");
-            //notification->setText( i18nc("@info","Please wait while %1 is being scanned for source files.", local()->sourceDir()) );
-            //notification->sendEvent();
         }
     }
     return m_sourceFilePaths;
@@ -499,7 +491,7 @@ void Project::projectOdfCreate()
     fi.absoluteDir().mkdir(trFolderName);
 
     QStringList args(odfPath);
-    args.append(fi.absoluteDir().absoluteFilePath(trFolderName) + '/' + fi.baseName() + QLatin1String(".xlf"));
+    args.append(fi.absoluteDir().absoluteFilePath(trFolderName) + QLatin1Char('/') + fi.baseName() + QLatin1String(".xlf"));
     qCDebug(LOKALIZE_LOG) << args;
     QProcess::execute(odf2xliff, args);
 
@@ -508,9 +500,9 @@ void Project::projectOdfCreate()
 
     Q_EMIT closed();
 
-    Project::instance()->load(fi.absoluteDir().absoluteFilePath(trFolderName) + QLatin1String("/index.lokalize"), targetLangCode, fi.baseName() + '-' + targetLangCode);
+    Project::instance()->load(fi.absoluteDir().absoluteFilePath(trFolderName) + QLatin1String("/index.lokalize"), targetLangCode, fi.baseName() + QLatin1Char('-') + targetLangCode);
 
     Q_EMIT fileOpenRequested(args.at(1), true);
 }
 
-
+#include "moc_project.cpp"
